An easy to use module that creates ODS documents. Fork of odslib (https://github.com/TauPan/odslib) as looking unmaintained. Applied Python3.x support.

Original author: Joseph Colton

Documentation: http://odslib3.readthedocs.io/en/master/

PyPi project page: https://pypi.python.org/pypi/odslib3


Installation::
#############
 
    $> git clone https://github.com/Exelscior/odslib3.git && cd odslib3

    $> python setup.py {build,install}
 
::
    
